@@ -28,17 +28,3 @@
 #' @keywords internal
 "_PACKAGE"
 
-#' @importFrom generics augment
-#' @export
-#' @seealso [augment.lm()]
-generics::augment
-
-#' @importFrom generics tidy
-#' @export
-#' @seealso [tidy.lm()]
-generics::tidy
-
-#' @importFrom generics glance
-#' @export
-#' @seealso [glance.lm()]
-generics::glance
